
import { View, Image, Text } from "@tarojs/components"
import Taro, { useDidShow } from '@tarojs/taro'
import ListPlaceholder from "@/components/ListPlaceholder"
import withLayout from '@/layouts'

import ordersListImga from '@/assets/ordersImages/ordersListImga.png'
import ordersLeft from '@/assets/ordersImages/ordersLeft.png'//订单装饰
import { useEffect, useState } from "react"
import { getOrder } from "@/services/order"
import formatTimes from "@/utils/codeSegment"
import { useModel } from "@/store"
import formatPrice from "@/utils/formatPrice"

import './OrdersCss/style.less'



export default withLayout((props) => {

  const [ourderList, setOrderList] = useState([])

  const [currentPage, setCurrentPage] = useState(1)

  const [isMore, setIsMore] = useState(false)

  const { person, setPerson } = useModel('userData')


  useDidShow(() => {
    getOrder({ pageNum: currentPage || 1, mine: true }).then((e) => {
      const { records } = e
      setOrderList(records)
    })
  })

  const handleScrollToLower = () => {
    if (ourderList.length < 9) {
      return;
    } else {
      setCurrentPage(currentPage + 1)

    }
  }
  useEffect(() => {
    getOrder({ pageNum: currentPage, mine: true }).then((e) => {
      const records = currentPage === 1 ? e.records || [] : ourderList.concat(e.records || [])
      console.log("🚀 ~ file: Orders.jsx ~ line 41 ~ getOrder ~ records", records)
      if (e.records.length == 0 && currentPage != 1) {
        setIsMore(true)
        return
      }
      // setJobList(lst)
      setOrderList(records)



    })
  }, [currentPage])
  console.log(ourderList, 'ourderList');

  const orderStates = (item) => {
    if (item.payStatus === 0) {
      return {
        title: '待付款',
        styleColor: '#51D4FF'
      }
    } else if (item.payStatus === 1 && item.workStatus === 0 && item.dispatchStatus === 0) {
      return {
        title: '已付款',
        styleColor: '#FF703B'
      }
    } else if (item.payStatus == 1 && item.dispatchStatus === 1 && item.workStatus === 0) {
      return {
        title: '待作业',
        styleColor: '#FF703B'
      }

    } else if (item.payStatus === 1 && (item.workStatus === 1 || item.workStatus === 2)) {
      return {
        title: '进行中',
        styleColor: '#44F68B'
      }
    } else if (item.workStatus === 3 && item.isEvaluated === 0) {
      return {
        title: '待评价',
        styleColor: '#51D4FF'
      }
    } if (item.workStatus === 3 && item.isEvaluated === 1 && item.dispatchStatus == 1) {
      return {
        title: '已完成',
        styleColor: '#FF703B'
      }
    } else if (item.payStatus === -1 && item.workStatus === 0 && item.isRefund === 1) {
      return {
        title: '已退单',
        styleColor: '#FF703B'
      }
    } else if (item.payStatus === 3 && (item.dispatchStatus == 1 || item.dispatchStatus == 0)) {
      return {
        title: '退单申请中',
        styleColor: '#FF703B'
      }
    } else {
      return {
        title: '异常',
        styleColor: '#FF0000'
      }
    }
  }

  const handleTobePaid = (id, stateType, stateStyle) => {
    Taro.navigateTo({ url: `/pages/OrderInfo/index?orderId=${id}&stateType=${stateType}&stateStyle=${stateStyle}` })
  }


  return (
    <scroll-view
      scrollY
      style='height: 100%;'
      onScrollToLower={isMore ? '' : handleScrollToLower}
    >

      <View className='content-header-box-orders'>
        <View className='content-header-box-orders-liftCentent'>
          <Image src={ordersListImga} />
          <View>订单列表</View>
        </View>
        {/* <View className='content-header-box-orders-rightCentent'>更多&gt;&gt;</View> */}
      </View>
      {
        ourderList?.length > 0 ? ourderList.map((item, index) => {
          return (
            <View key={index} className='orders-listBox'>
              <Image src={ordersLeft} />
              <View className='orders-listBox-RihtboxBoxOrderViewText'>
                <View className='View-LiftTextTop' onClick={() => handleTobePaid(item.orderId, orderStates(item)?.title, orderStates(item)?.styleColor)} >
                  订单编号：<Text>{item.orderNo}</Text><Text className='View-LiftTextTop-nextText'>更多&gt;&gt;</Text></View>
                <View>农机名称：<Text>{item.machineryName}</Text></View>
                <View>作业面积：<Text>{item.amount}</Text></View>
                <View>需求时间：<Text>{formatTimes(item.appointmentDate, 'yyyy-MM-dd')}</Text></View>
                <View>下单时间：<Text>{formatTimes(item.createDate, 'yyyy-MM-dd')}</Text></View>
                <View className='View-LiftTextBotton'>
                  <View>订单状态：<Text style={{ color: orderStates(item)?.styleColor }} >{orderStates(item)?.title}</Text></View>
                  <View>费用：<Text className='feiyongStyle'>{formatPrice(item.charges)}</Text></View>
                </View>
              </View>
            </View>
          )
        })
          : <ListPlaceholder title='您还没有新的订单！' />
      }


    </scroll-view>
  )
})
