import { useCallback, useEffect, useRef } from "react";



/**
 * object 转 queryStr
 * @param {*} params 
 * @returns 
 */
export function getQueryString (params) {
  if (!params) return;

  const keys = Object.keys(params)
  const arr = keys.map((key) => {
    const val = params[key]
    if (val === null || val === undefined) return false;

    return `${key}=${encodeURIComponent(val)}`
  })

  return arr.filter(Boolean).join('&')
}




//日期格式化
function getDateByStr (dtStr) {
  if (!dtStr) return undefined;

  const t = dtStr.split(/[-T :]/);
  return new Date(t[0], t[1] - 1, t[2], t[3] || 0, t[4] || 0, t[5] || 0)
}

export default function formatTimes (dt, fmt) {
  if (!dt) return dt;

  // 解决苹果手机不能正常初始化的问题
  const date = typeof dt === 'string' ? getDateByStr(dt) : new Date(dt);

  var o = {
    "M+": date.getMonth() + 1, //月份
    "d+": date.getDate(), //日
    "h+": date.getHours(), //小时
    "m+": date.getMinutes(), //分
    "s+": date.getSeconds(), //秒
    "q+": Math.floor((date.getMonth() + 3) / 3), //季度
    "S": date.getMilliseconds() //毫秒
  };
  if (/(y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
  for (var k in o)
    if (new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
  return fmt;
};



export function setMorKm (m) {
  var n = ''
  if (m) {
    if (m >= 1000) {
      n = (m / 1000).toFixed(2) + '公里'
    } else {
      n = m + '米'
    }
  } else {
    n = '0m'
  }
  return n
}



// 节流
export function useThrottle (fn, delay, dep = []) {
  const { current } = useRef({ fn, timer: null })
  useEffect(
    function () {
      current.fn = fn
    },
    [fn]
  )
  return useCallback(function f (...args) {
    if (!current.timer) {
      current.timer = setTimeout(() => {
        delete current.timer
      }, delay)
      current.fn.call(this, ...args)
    }
  }, dep)
}

